set terminal postscript eps enhanced mono 28 dashlength 4
set ylabel "Cycles to failure"
set xlabel "Maximum stress / GPa" 1.5
set size square
set logscale y
SMIN=0.81
SMAX=2.29
CYMIN=0.3
CYMAX=1e7

set xrange [SMIN:SMAX]
set yrange [CYMIN:CYMAX]
set nokey
#set title "SP9C Low Cycle Fatigue, 0.25 Hz, R=0.1"
set arrow 1 from first 1.2, 100000 to first 1.2, 180000 lw 3 lt 1 head filled
set arrow 2 from first 1.3, 100000 to first 1.3, 180000 lw 3 lt 1 head filled
set arrow 4 from first SMIN, 100000 to first SMAX, 100000 ls 2 nohead 

set output "Sp9c_life.eps"
plot "results.txt" pt 6 ps 2



set xlabel "Cycles to failure"
set ylabel "Maximum stress / GPa" 1.5
set nologscale y
set logscale x
set yrange [SMIN:SMAX]
set xrange [CYMIN:CYMAX]
set arrow 1 from first 100000,1.2 to first 180000,1.2 lw 3 lt 1 head filled
set arrow 2 from first 100000,1.3 to first 180000,1.3 lw 3 lt 1 head filled
set arrow 4 from first 100000,SMIN to first 100000,SMAX ls 2 nohead 
set output "Sp9c_life_andy.eps
plot "results.txt" using 2:1 pt 6 ps 2


set xlabel "Cycles to failure"
set ylabel "Stress range / GPa" -0.5
set nologscale y
set logscale x
set yrange [0.9*SMIN:0.9*SMAX]
set xrange [CYMIN:CYMAX]
set arrow 1 from first 100000,0.9*1.2 to first 180000,0.9*1.2 lw 3 lt 1 head filled
set arrow 2 from first 100000,0.9*1.3 to first 180000,0.9*1.3 lw 3 lt 1 head filled
set arrow 4 from first 100000,0.9*SMIN to first 100000,0.9*SMAX ls 2 nohead 
set output "Sp9c_life_radu.eps
plot "results.txt" using 2:(0.9*$1) pt 6 ps 2
set format x "10^{%L}"

set output "Sp9c_life_radu2.eps
plot "results.txt" using 2:(0.9*$1) pt 6 ps 2



set xlabel "Cycles to failure"
set ylabel "Stress range / GPa" -0.5
set ytics nomirror
set y2label "Maximum Stress / GPa"
set nologscale y
set logscale x
set yrange [0.9*SMIN:0.9*SMAX]
set y2range [SMIN:SMAX]
set y2tics 0.2
set format x "10^{%L}"
set  xrange [CYMIN:CYMAX]
set arrow 1 from first 100000,0.9*1.2 to first 180000,0.9*1.2 lw 3 lt 1 head filled
set arrow 2 from first 100000,0.9*1.3 to first 180000,0.9*1.3 lw 3 lt 1 head filled
set arrow 4 from first 100000,0.9*SMIN to first 100000,0.9*SMAX ls 2 nohead 
set label "R = 0.1" at graph 0.1,0.12
set output "Sp9c_life_mathew.eps
plot "results.txt" index 0:0 using 2:(0.9*$1) pt 6 ps 2, \
     "results.txt" index 1:1 using 2:(0.9*$1) pt 7 ps 2, \
     "results.txt" index 2:2 using 2:(0.9*$1) pt 4 ps 2



set xlabel "Cycles to failure"
set y2label "Stress Range / GPa" -0.5
set ytics nomirror
set ylabel "Maximum Stress / GPa" 1.5
set nologscale y
set logscale x
set y2range [0.9*SMIN:0.9*SMAX]
set yrange [SMIN:SMAX]
set y2tics 1, 0.2, 1.6
set format x "10^{%L}"
set xrange [CYMIN:CYMAX]
set arrow 1 from first 100000,1.2 to first 1000000,1.2 lw 3 lt 1 head filled
set arrow 2 from first 100000,1.3 to first 1000000,1.3 lw 3 lt 1 head filled
set arrow 4 from first 100000,SMIN to first 100000,SMAX ls 2 nohead 
set label "test limit" at 2*10**5, 1.8 rotate by 90
set label "R = 0.1" at graph 0.1,0.12
set output "Sp9c_life_mathew2.eps
plot "results.txt" index 0:0 using 2:1 pt 6 ps 2, \
     "results.txt" index 1:1 using 2:1 pt 7 ps 2, \
     "results.txt" index 2:2 using 2:1 pt 4 ps 2



h(x) = e + f*x
fit h(x) "results.txt" index 0:0 using (log($2)):1 via e,f


set output "Sp9c_life_mathew2_reg.eps"
plot "results.txt" index 0:0 using 2:1 pt 6 ps 2, \
     "results.txt" index 1:1 using 2:1 pt 7 ps 2, \
     "results.txt" index 2:2 using 2:1 pt 4 ps 2, \
      h(log(x))


print "Expected Stress for sample that fails 10^7 (fatigue limit) =",h(log(10**7)), " GPa"
print "Expected Stress for sample that fails 10^8                 =",h(log(10**8)), " GPa"

